@@ -1,6 +1,7 @@
 /** TODO update refresh to only refresh data( not window) **/
 let idleTime = 0;
 let orderPrintJson = '';
+
 function timerIncrement() {
     idleTime = idleTime + 1;
     console.log(idleTime);
@@ -8,8 +9,9 @@ function timerIncrement() {
         window.location.reload();
     }
 }
+
 (function () {
-    setInterval (timerIncrement, 60000);
+    setInterval(timerIncrement, 60000);
     $(this).mousemove(function (e) {
         idleTime = 0;
     });
@@ -45,6 +47,11 @@ function submitNote() {
     }
 }
 
+function markNew(value, config){
+    if (value === "New Order")
+        return { "border":"1px solid #ea7600 !important" };
+    return value;
+};
 
 (function () {
 
@@ -60,9 +67,9 @@ function submitNote() {
                 newOrderCount++;
             } else if (val.status === '5') {
                 readyOrderCount++;
-            }else if (val.status === '6') {
+            } else if (val.status === '6') {
                 collectedCount++;
-            } else if(val.status !== '5' || val.status !== '6') {
+            } else if (val.status !== '5' || val.status !== '6') {
                 toMakeCount++;
             }
         });
@@ -75,14 +82,15 @@ function submitNote() {
             {id: 2, value: "Awaiting Processing"},
             {id: 3, value: "Started"},
             {id: 4, value: "Being Collated"},
-            {id: 5, value: "Ready for collection"},
+            {id: 5, value: "&#9993; Ready for collection"},
             {id: 6, value: "Collected"},
             {id: 7, value: "Cancelled"},
             {id: 8, value: "Not Collected"},
+            {id: 9, value: "Collection Date Changed"},
         ];
 
         val.orders.conditions = [
-            [1,5,"=",'Cancelled',"cancelled"],
+            [1, 5, "=", 'Cancelled', "cancelled"],
         ];
 
 
@@ -100,33 +108,34 @@ function submitNote() {
                         view: "datatable",
                         editable: true,
                         footer: true,
-                        responsive:true,
+                        responsive: true,
                         id: "box" + i,
                         position: "center",
-                        rowHeight: 65,
+                        rowHeight: 80,
                         columns: [
-                            {width:25},
+                            {width: 25},
                             {
                                 id: "id",
                                 header: "Web order No.",
-                                css: {'font-weight':'bold'},
-                                footer: "<div class='webix_el_button'><a class='print_all' href='/content/plugins/click-collect-plugin/templates/print-all-orders.php?location="+getUrlParameter('location')+"&date="+i+"'>Print all</a></div>",
+                                css: {'font-weight': 'bold'},
+                                footer: "<div class='webix_el_button'><a class='print_all' href='/content/plugins/click-collect-plugin/templates/print-all-orders.php?location=" + getUrlParameter('location') + "&date=" + i + "&status=all'>Print all</a></div>",
                                 width: 150
                             },
-                            {id: "client_name", header: "Client Name", width: 250},
+                            {id: "client_name", header: "Client Name", width: 150},
                             {id: "contact_number", header: "Contact Number", width: 150},
                             {
                                 id: "status",
-                                css:"select_column",
+                                css: "select_column",
                                 header: "Status",
-                                footer: "<div class='webix_el_button'><a href='/content/plugins/click-collect-plugin/templates/print-all-orders.php?location="+getUrlParameter('location')+"&date="+i+"&?status=to-be-made' class='print_all_awaiting'>Print orders to be made up</a></div>",
+                                footer: "<div class='webix_el_button'><a href='/content/plugins/click-collect-plugin/templates/print-all-orders.php?location=" + getUrlParameter('location') + "&date=" + i + "&status=to-be-made' class='print_all_awaiting'>Print New</a></div>",
                                 fillspace: true,
                                 editor: 'richselect',
-                                options: order_status
+                                options: order_status,
+                                cssFormat:markNew
                             },
                             {
                                 id: "shop_order_number",
-                                css:{"font-weight":"bold", 'text-align':'center'},
+                                css: {"font-weight": "bold", 'text-align': 'center'},
                                 header: "Shop Order No.",
                                 width: 150,
                                 editor: 'text'
@@ -135,7 +144,7 @@ function submitNote() {
                                 id: "action", header: "Action",
                                 fillspace: true,
                                 template: function (obj) {
-                                    return "<div class='webix_el_button'><button class='add_notes'> Add Notes</button></div><div class='webix_el_button'><button class='view_order'> View</button></div>";
+                                    return "<div class='webix_el_button'><button class='add_notes'> Add Notes</button></div><div class='webix_el_button'><button class='view_order'> View Order</button></div>";
                                 },
                                 width: 250
                             }
@@ -153,9 +162,9 @@ function submitNote() {
                                     if (editor.column === 'status') {
                                         webix.ajax("/wp-json/click-collect/v1/update-order-status/" + state.value + '/' + editor.row, function (text, data, xhr) {
                                             console.log(state.value);
-                                            if(text === '"Order not Updated, please check you have input the shop number and final price"') {
+                                            if (text === '"Order not Updated, please check you have input the shop number and final price"') {
                                                 webix.message({type: "message-style", text: text});
-                                                location.reload();
+                                                setTimeout(window.location.reload.bind(window.location), 2000);
                                             } else {
                                                 webix.message({type: "message-style", text: text});
                                             }
@@ -168,8 +177,8 @@ function submitNote() {
 
                         autoheight: true,
                         data: val.orders,
-                        conditionStyle:[
-                            {name:'red', css:"cancelled"}
+                        conditionStyle: [
+                            {name: 'red', css: "cancelled"}
                         ],
                         onClick: {
                             "add_notes": function (e, id, trg) {
@@ -191,7 +200,7 @@ function submitNote() {
                                             modal: true,
                                             position: "center",
                                             width: 1200,
-                                            height: 800,
+                                            height: 500,
                                             borderless: true,
                                             body: {
                                                 rows: [
@@ -247,11 +256,12 @@ function submitNote() {
                                 webix.message({type: "message-style", text: "Loading order: " + id});
                                 webix.ajax("/wp-json/click-collect/v1/get-orders/" + id, function (text, data, xhr) {
                                     windowInfo = data.json();
+                                    console.log(windowInfo);
                                     if (windowInfo) {
                                         webix.ui({
                                             view: "window",
                                             id: "order_window",
-                                            padding:50,
+                                            padding: 50,
                                             head: {
                                                 cols: [{template: ''}, {}, {
                                                     view: "icon",
@@ -259,21 +269,21 @@ function submitNote() {
                                                     click: ("location.reload();")
                                                 }]
                                             },
-                                            autowidth: true,
                                             position: "center",
                                             autoheight: 650,
-                                            scroll:"y",
+                                            scroll: "y",
                                             move: true,
-                                            modal:true,
+                                            modal: true,
                                             body: {
+                                                width:1000,
                                                 rows: [
                                                     {
                                                         height: 250,
                                                         cols: [
-                                                            {width:50},
+                                                            {width: 50},
                                                             {
-                                                                width: 500,
-                                                                css:"print-smaller",
+                                                                width: 600,
+                                                                css: "print-smaller",
                                                                 rows: [
                                                                     {
                                                                         template: '<strong>Date for Collection: </strong>' + windowInfo.pickup_date,
@@ -303,7 +313,7 @@ function submitNote() {
                                                                                 template: "<strong>Estimated Price: </strong>£" + windowInfo.price,
                                                                                 borderless: true,
                                                                                 autoheight: true,
-                                                                                width:250
+                                                                                width: 250
                                                                             },
                                                                             {
                                                                                 view: "text",
@@ -311,8 +321,8 @@ function submitNote() {
                                                                                 label: "<strong>Actual Price: £</strong>",
                                                                                 placeholder: "Input Final Price",
                                                                                 borderless: true,
-                                                                                width:220,
-                                                                                labelWidth:125,
+                                                                                width: 300,
+                                                                                labelWidth: 125,
                                                                                 labelAlign: 'right',
                                                                                 value: item.final_price
                                                                             },
@@ -321,77 +331,45 @@ function submitNote() {
                                                                 ]
                                                             },
                                                             {
-                                                                width:350,
+                                                                width: 300,
                                                                 rows: [
                                                                     {
-                                                                        css:'border_box',
+                                                                        css: 'border_box',
                                                                         view: "text",
                                                                         id: "shop_number",
                                                                         value: item.shop_order_number,
                                                                         label: 'Shop Order No.',
-                                                                        labelWidth:175,
+                                                                        labelWidth: 175,
                                                                     },
-                                                                    {height:25},
+                                                                    {height: 25},
                                                                     {
-                                                                        css:'border_box',
+                                                                        css: 'border_box',
                                                                         view: "select",
                                                                         id: "status_select",
                                                                         label: "Status",
                                                                         options: order_status,
                                                                         value: item.status,
-                                                                        labelWidth:175,
+                                                                        labelWidth: 175,
                                                                     },
                                                                     {},
                                                                     {},
                                                                     {},
                                                                     {},
-                                                                    {
-                                                                        css:'hidden_window',
-                                                                        id:'label_window',
-                                                                        height:1,
-                                                                        rows:[
-                                                                            {
-                                                                                template: '<strong>Shop Order Number: </strong>' + item.shop_order_number,
-                                                                                borderless: true,
-                                                                                autoheight: true
-                                                                            },
-                                                                            {
-                                                                                template: '<strong>Phone Number: </strong>' + item.contact_number,
-                                                                                borderless: true,
-                                                                                autoheight: true
-
-                                                                            },
-                                                                            {
-                                                                                template: '<strong>Client Name: </strong>' + item.client_name,
-                                                                                borderless: true,
-                                                                                autoheight: true
-                                                                            },
-                                                                            {
-                                                                                template: '<strong>Collection Date: </strong>' + val.date,
-                                                                                borderless: true,
-                                                                                autoheight: true
-                                                                            },
-
-                                                                        ]
-
-                                                                    },
                                                                     {
                                                                         borderless: true,
                                                                         autoheight: true,
                                                                         template: function (obj) {
-                                                                            return "<div class='webix_el_button'><button class='add_notes'> Add Notes</button></div><div class='webix_el_button'><button class='print_order'> Print Order</button></div><div class='webix_el_button'><button class='print_label'> Print Label</button></div>";
+                                                                            return "<div class='webix_el_button'><button class='add_notes'> Add Notes</button></div><div class='webix_el_button'><a class='print_order' href='/content/plugins/click-collect-plugin/templates/print-single-order.php?location=" + getUrlParameter('location') + "&order="+item.id+"&date=" + i + "'>Print Order</a></div><div class='webix_el_button'><a class='print_order' href='/content/plugins/click-collect-plugin/templates/print-label.php?shopNo="+$$('shop_number').getValue()+"&number=" + item.contact_number + "&client="+item.client_name+"&date=" + i + "&location="+getUrlParameter('location')+"'>Print Label</a></div>";
                                                                         },
                                                                         onClick: {
-                                                                            "print_order": function (e, id, trg) {
-                                                                                webix.print($$("order_window"), {
-                                                                                    mode: "portrait",
-                                                                                    fit: "page"
-                                                                                });
-                                                                            },
                                                                             "print_label": function (e, id, trg) {
+                                                                                var orderNo = $$('shop_number').getValue();
+                                                                                console.log(orderNo);
+                                                                                $$('print_order_number').setValue(orderNo);
                                                                                 webix.print($$("label_window"), {
                                                                                     mode: "landscape",
-                                                                                    fit: "page"
+                                                                                    fit: "data",
+                                                                                    paper: 'a4'
                                                                                 });
                                                                             },
                                                                             "add_notes": function (e, id, trg) {
@@ -419,7 +397,7 @@ function submitNote() {
                                                                                             modal: true,
                                                                                             position: "center",
                                                                                             width: 1200,
-                                                                                            height: 800,
+                                                                                            height:500,
                                                                                             borderless: true,
                                                                                             body: {
                                                                                                 rows: [
@@ -478,18 +456,55 @@ function submitNote() {
                                                                             }
                                                                         }
                                                                     },
+                                                                    {
+                                                                        css: 'hidden_window',
+                                                                        id: 'label_window',
+                                                                        width:3000,
+                                                                        height: 1,
+                                                                        rows: [
+                                                                            {
+                                                                                css: 'border_box',
+                                                                                view: "text",
+                                                                                id: "print_order_number",
+                                                                                value: '',
+                                                                                label: 'Shop Order No.',
+                                                                                labelWidth: 175,
+                                                                            },
+                                                                            {
+                                                                                template: '<p><strong>Phone Number: </strong>' + item.contact_number+'</p>',
+                                                                                borderless: true,
+                                                                                height: 140,
+                                                                                width:3000
+
+                                                                            },
+                                                                            {
+                                                                                template: '<p><strong>Client Name: </strong>' + item.client_name+'</p>',
+                                                                                borderless: true,
+                                                                                height: 140,
+                                                                                width:3000
+                                                                            },
+                                                                            {
+                                                                                template: '<p><strong>Collection Date: </strong>' + val.date+'</p>',
+                                                                                borderless: true,
+                                                                                height: 140,
+                                                                                width:3000
+                                                                            },
+
+                                                                        ]
+
+                                                                    },
                                                                 ]
                                                             },
-                                                            {width:50},
+                                                            {width: 50},
                                                         ]
                                                     },
                                                     {height: 45, borderless: true},
                                                     {
                                                         cols: [
-                                                            {width:50},
+                                                            {width: 50},
                                                             {
                                                                 template: '<h2>Items in order:</h2>',
-                                                                padding:50,
+                                                                padding: 50,
                                                                 autoheight: true,
                                                                 borderless: true
 
@@ -498,28 +513,46 @@ function submitNote() {
                                                     },
                                                     {
                                                         view: "datatable",
-                                                        id:"window_order_table",
-                                                        rowHeight: 65,
-                                                        height:300,
-                                                        scroll:"y",
+                                                        id: "window_order_table",
+                                                        rowHeight: 75,
+                                                        height: 300,
+                                                        scroll: "y",
                                                         columns: [
-                                                            {width:50},
-                                                            {id: 'product_thumbnail', header: '', template:function(obj){
-                                                                    return "<img style='display:block; ' src='"+obj.product_thumbnail+"'/>";
-                                                                }
+                                                            {width: 50},
+                                                            {
+                                                                id: 'product_thumbnail',
+                                                                header: '',
+                                                                template: function (obj) {
+                                                                    return "<img style='display:block; ' src='" + obj.product_thumbnail + "'/>";
+                                                                },
+                                                                autowidth:true,
+                                                                css:'hidden-column'
                                                             },
                                                             {
                                                                 id: 'product_title',
                                                                 header: 'Product Title',
-                                                                css:'print-column',
-                                                                width:200
+                                                                css: 'print-column',
+                                                                fillspace:true
                                                             },
-                                                            {id: 'weight', header: 'Weight (g)', css:'print-column'},
-                                                            {id: 'people', header: 'No. of People',css:'print-column'},
-                                                            {id: 'size', header: 'by Pack Size', css:'print-column'},
-                                                            {id: 'qty', header: 'Quantity', css:'print-column'},
-                                                            {width:50}
+                                                            {id: 'weight', header: 'Weight (g)', css: 'print-column'},
+                                                            {
+                                                                id: 'unit_label',
+                                                                header: 'Unit Label',
+                                                                fillspace:true,
+                                                                css: 'print-column'
+                                                            },
+                                                            {
+                                                                id: 'unit',
+                                                                header: 'Units',
+                                                                css: 'print-column'
+                                                            },
+                                                            {id: 'size', header: 'by Pack Size', fillspace:true, css: 'print-column'},
+                                                            {id: 'qty', header: 'Qty', css: 'print-column'},
+                                                            {id: 'sku', header: 'SKU', css: 'print-column'},
+                                                            {width: 50}
                                                         ],
+                                                        fixedRowHeight:false,
+                                                        rowLineHeight:25,
                                                         data: windowInfo.orders
                                                     }
                                                 ]
@@ -540,21 +573,23 @@ function submitNote() {
                                         $$("final_price").attachEvent("onBlur", function () {
                                             console.log($$('final_price').getValue());
                                             formValues = $$('final_price').getValue();
-                                            webix.ajax().post("/wp-json/click-collect/v1/set-final-price/",{
-                                                action: "finalPrice",
-                                                formValues,
-                                                id
-                                            }, function (text, data, xhr) {
-                                                webix.message({type: "message-style", text: "Final Price saved"});
+                                            console.log($$('final_price').getValue());
+                                            if ($$('final_price').getValue() != '') {
+                                                webix.ajax().post("/wp-json/click-collect/v1/set-final-price/", {
+                                                    action: "finalPrice",
+                                                    formValues,
+                                                    id
+                                                }, function (text, data, xhr) {
+                                                    webix.message({type: "message-style", text: "Final Price saved"});
 
-                                            });
+                                                });
+                                            }
                                         });
 
                                         $$("status_select").attachEvent("onChange", function () {
                                             webix.ajax("/wp-json/click-collect/v1/update-order-status/" + $$('status_select').getValue() + '/' + id, function (text, data, xhr) {
-                                                if(text === '"Order not Updated, please check you have input the shop number and final price"') {
+                                                if (text === '"Order not Updated, please check you have input the shop number and final price"') {
                                                     webix.message({type: "message-style", text: text});
-                                                    location.reload();
                                                 } else {
                                                     webix.message({type: "message-style", text: text});
                                                 }
